@@ -16,7 +16,7 @@ test_that("orbital works with workflows - recipe", {
   obj <- orbital(wf_fit)
 
   expect_identical(
-    mtcars %>% orbital_predict(obj),
+    predict(obj, mtcars),
     mtcars %>% dplyr::mutate(!!!orbital_inline(obj)) %>% dplyr::select(.pred)
   )
 })
