@@ -20,7 +20,7 @@ test_that("sql works", {
   con <- dbplyr::simulate_dbi()
 
   expect_snapshot(
-    transform = pretty_print,
+    transform = orbital:::pretty_print,
     orbital_sql(obj, con)
   )
 })
